Welcome to svg.charts documentation!
====================================

.. toctree::
   :maxdepth: 2
   :glob:

   svg.charts
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

